==> wawa-service-common-0.0.25-20180301.063509-3-sources.jar: cn/com/wawa/common/constants/KeepAliveConstants.java <==
package cn.com.wawa.common.constants;

/**
 * Created by danke on 2017/11/27.
 */
public class KeepAliveConstants {
    private KeepAliveConstants() {
    }

    public interface MQMsgBodyKey{
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
        String MSG_SUM = "sum";
        String MSG_USER = "user";
        String MSG_DATA_ORDERID = "orderId";
        String MSG_DATA_USERID = "userId";
        String MSG_DATA_ROOMID = "roomId";
        String MSG_DATA_ISCHTCHED = "isCatched";

        String MSG_DATA_CATCHERID = "catcherId";
        String MSG_DATA_CATCHER_CAUGHT_NUM = "caughtNum";
        String MSG_DATA_USER_NAME = "userName";
        String MSG_DATA_USER_CATCH_NUM = "userCatchNum";
        String MSG_DATA_USER_CAUGHT_WAWA_NAME = "caughtWawaName";
        String MSG_DATA_USER_CAUGHT_MSG = "caughtWawaMsg";

        String MSG_DATA_CENTER_MSG_UNCHECK_NUM = "centerMsgUnChackNum";

        //电压配置发送娃娃机消息key
        String MSG_CONFIG_MACHINE = "config";
        String MSG_CMD_MACHINE = "cmd";
        String MSG_ID_MACHINE = "machineId";
        String MSG_STRONG_MACHINE = "strong";

    }

    public interface CatchedStatus{
        String isCatched = "20300";
        String unCatched = "20301";
    }

    public interface HandlerKey{
        String ONLOOK_HANDLER_KEY = "10001";//客户端围观队列心跳消息类型
    }

    public interface ProxyPushMsgKey{
        String MSG_USERID = "userId";
        String MSG_CATCHERID = "catcherId";
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
    }

    /**
     * 用户进出房间行为标记常量
     */
    public interface UserJoin{
        int USER_IN = 1;
        int USER_OUT = 0;
    }
}

==> wawa-service-common-0.0.30-sources.jar: cn/com/wawa/common/constants/KeepAliveConstants.java <==
package cn.com.wawa.common.constants;

/**
 * Created by danke on 2017/11/27.
 */
public class KeepAliveConstants {
    private KeepAliveConstants() {
    }

    public interface MQMsgBodyKey{
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
        String MSG_SUM = "sum";
        String MSG_USER = "user";
        String MSG_DATA_ORDERID = "orderId";
        String MSG_DATA_USERID = "userId";
        String MSG_DATA_ROOMID = "roomId";
        String MSG_DATA_ISCHTCHED = "isCatched";

        String MSG_DATA_CATCHERID = "catcherId";
        String MSG_DATA_CATCHER_CAUGHT_NUM = "caughtNum";
        String MSG_DATA_USER_NAME = "userName";
        String MSG_DATA_USER_CATCH_NUM = "userCatchNum";
        String MSG_DATA_USER_CAUGHT_WAWA_NAME = "caughtWawaName";
        String MSG_DATA_USER_CAUGHT_MSG = "caughtWawaMsg";

        String MSG_DATA_CENTER_MSG_UNCHECK_NUM = "centerMsgUnChackNum";

        //电压配置发送娃娃机消息key
        String MSG_CONFIG_MACHINE = "config";
        String MSG_CMD_MACHINE = "cmd";
        String MSG_ID_MACHINE = "machineId";
        String MSG_STRONG_MACHINE = "strong";

    }

    public interface CatchedStatus{
        String isCatched = "20300";
        String unCatched = "20301";
    }

    public interface HandlerKey{
        String ONLOOK_HANDLER_KEY = "10001";//客户端围观队列心跳消息类型
        String USER_TALK_KEY = "10002";//用户聊天消息类型
    }

    public interface ProxyPushMsgKey{
        String MSG_USERID = "userId";
        String MSG_CATCHERID = "catcherId";
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
        String MSG_TALK_CXT = "dialogContent";
        String MSG_USER_NAME = "nickName";
        String MSG_SEND_TIME = "sendTime";
        String MSG_DIALOG_TYPE = "dialogType";
        String MSG_USER_TITLE_PIC = "userTitlePic";
    }

    /**
     * 用户进出房间行为标记常量
     */
    public interface UserJoin{
        int USER_IN = 1;
        int USER_OUT = 0;
    }
}
